@@ -3,10 +3,11 @@ get_predictions_clm <- function(model, data_grid, ci.lvl, linv, ...) {
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
 
   # compute ci, two-ways
-  if (!is.null(ci.lvl) && !is.na(ci.lvl))
+  if (!is.null(ci.lvl) && !is.na(ci.lvl)) {
     ci <- ci.lvl
-  else
+  } else {
     ci <- 0.95
+  }
 
   # prediction, with CI
   prdat <- stats::predict(
@@ -25,7 +26,7 @@ get_predictions_clm <- function(model, data_grid, ci.lvl, linv, ...) {
   data_grid <- cbind(prdat, data_grid)
 
   # get levels of response
-  lv <- levels(insight::get_response(model))
+  lv <- levels(insight::get_response(model, verbose = FALSE))
 
   # for proportional ordinal logistic regression (see ordinal::clm),
   # we have predicted values for each response category. Hence,
@@ -33,7 +34,6 @@ get_predictions_clm <- function(model, data_grid, ci.lvl, linv, ...) {
   # category, we need to gather multiple columns at once
 
   if (isTRUE(se)) {
-
     # length of each variable block
     l <- seq_len(ncol(prdat) / 3)
     colnames(data_grid)[l] <- lv
@@ -44,7 +44,6 @@ get_predictions_clm <- function(model, data_grid, ci.lvl, linv, ...) {
       values_to = c("predicted", "conf.low", "conf.high"),
       columns = list(l, l + length(l), l + 2 * length(l))
     )
-
   } else {
     data_grid <- .gather(
       data_grid,
