@@ -32,54 +32,64 @@
 # all valid "type" arguments for each model class
 .typedic <- data.frame(
   class = c(
-    "other", "other", "other", "bam", "bam",
-    "bart", "bart", "betareg", "betareg", "betareg", "betareg", "betareg",
-    "bife", "bife", "bracl", "brglmFit", "brglmFit", "brmsfit", "brmsfit",
-    "brmsfit", "brmsfit", "brmultinom", "brmultinom", "clm", "clm",
-    "clm", "clogit", "clogit", "clogit", "clogit", "coxph", "coxph",
-    "coxph", "coxph", "crch", "crch", "crch", "crch", "hetprob",
-    "hetprob", "hxlr", "hxlr", "hxlr", "hxlr", "ivpml", "ivpml",
+    "bam", "bam", "bart", "bart", "betareg", "betareg", "betareg",
+    "betareg", "betareg", "bife", "bife", "bracl", "brglmFit", "brglmFit",
+    "brmsfit", "brmsfit", "brmsfit", "brmsfit", "brmultinom", "brmultinom",
+    "clm", "clm", "clm", "clogit", "clogit", "clogit", "clogit",
+    "coxph", "coxph", "coxph", "coxph", "coxph_weightit", "coxph_weightit",
+    "coxph_weightit", "coxph_weightit", "crch", "crch", "crch", "crch",
+    "hetprob", "hetprob", "hxlr", "hxlr", "hxlr", "hxlr", "ivpml",
+    "ivpml", "flexsurvreg", "flexsurvreg", "flexsurvreg", "flexsurvreg",
+    "flexsurvreg", "flexsurvreg", "flexsurvreg", "flexsurvreg", "flexsurvreg",
     "fixest", "fixest", "fixest", "hurdle", "hurdle", "hurdle", "hurdle",
     "iv_robust", "lm", "gam", "gam", "Gam", "Gam", "Gam", "geeglm",
     "geeglm", "Gls", "glimML", "glimML", "glm", "glm", "glm", "glmerMod",
-    "glmerMod", "glmrob", "glmrob", "glmmTMB", "glmmTMB", "glmmTMB",
-    "glmmTMB", "glmmTMB", "glmmTMB", "glmmPQL", "glmmPQL", "glmx",
-    "ivreg", "lmerMod", "lmerModLmerTest", "lmrob", "lm_robust",
-    "lrm", "lrm", "lrm", "mblogit", "mblogit", "mblogit", "mclogit",
-    "mclogit", "mclogit", "MCMCglmm", "model_fit", "model_fit", "model_fit",
-    "workflow", "workflow", "workflow", "multinom", "multinom", "mhurdle",
-    "mhurdle", "mhurdle", "mlogit", "mvgam", "mvgam", "mvgam", "mvgam",
-    "mvgam", "negbin", "negbin", "negbin", "ols", "oohbchoice", "oohbchoice",
-    "orm", "orm", "orm", "polr", "rlm", "selection", "selection",
+    "glmerMod", "glmgee", "glmrob", "glmrob", "glmmTMB", "glmmTMB",
+    "glmmTMB", "glmmTMB", "glmmTMB", "glmmTMB", "glmmPQL", "glmmPQL",
+    "glmx", "glm_weightit", "glm_weightit", "glm_weightit", "glm_weightit",
+    "glm_weightit", "ivreg", "lmerMod", "lmerModLmerTest", "lmrob",
+    "lm_robust", "lrm", "lrm", "lrm", "mblogit", "mblogit", "mblogit",
+    "mclogit", "mclogit", "mclogit", "MCMCglmm", "model_fit", "model_fit",
+    "model_fit", "workflow", "workflow", "workflow", "multinom",
+    "multinom", "multinom_weightit", "multinom_weightit", "multinom_weightit",
+    "mhurdle", "mhurdle", "mhurdle", "mlogit", "mvgam", "mvgam",
+    "mvgam", "mvgam", "mvgam", "negbin", "negbin", "negbin", "ols",
+    "oohbchoice", "oohbchoice", "orm", "orm", "orm", "ordinal_weightit",
+    "ordinal_weightit", "ordinal_weightit", "ordinal_weightit", "ordinal_weightit",
+    "polr", "rendo.base", "rendo.base", "rlm", "selection", "selection",
     "selection", "speedlm", "speedglm", "speedglm", "stanreg", "stanreg",
     "survreg", "survreg", "survreg", "svyglm", "svyglm", "svyolr",
     "tobit", "tobit1", "tobit1", "tobit1", "zeroinfl", "zeroinfl",
     "zeroinfl", "zeroinfl"
   ),
   type = c(
-    "response", "class", "link",
     "response", "link", "ev", "ppd", "response", "link", "precision",
     "quantile", "variance", "response", "link", "probs", "response",
     "link", "response", "link", "prediction", "average", "probs",
     "class", "prob", "cum.prob", "linear.predictor", "expected",
     "lp", "risk", "survival", "expected", "lp", "risk", "survival",
-    "response", "location", "scale", "density", "pr", "xb", "location",
-    "cumprob", "scale", "density", "pr", "xb", "invlink(link)", "response",
+    "expected", "lp", "risk", "survival", "response", "location",
+    "scale", "density", "pr", "xb", "location", "cumprob", "scale",
+    "density", "pr", "xb", "response", "mean", "link", "lp", "linear",
+    "rmst", "survival", "hazard", "cumhaz", "invlink(link)", "response",
     "link", "response", "prob", "count", "zero", "response", "response",
     "response", "link", "invlink(link)", "response", "link", "response",
     "link", "lp", "response", "link", "invlink(link)", "response",
-    "link", "response", "link", "response", "link", "response", "link",
-    "conditional", "zprob", "zlink", "disp", "response", "link",
-    "response", "response", "response", "response", "response", "response",
+    "link", "response", "link", "response", "response", "link", "response",
+    "link", "conditional", "zprob", "zlink", "disp", "response",
+    "link", "response", "invlink(link)", "probs", "response", "lp",
+    "link", "response", "response", "response", "response", "response",
     "fitted", "lp", "mean", "response", "latent", "link", "response",
     "latent", "link", "response", "numeric", "prob", "class", "numeric",
-    "prob", "class", "probs", "latent", "E", "Ep", "p", "response",
-    "response", "link", "expected", "detection", "latent_N", "invlink(link)",
-    "response", "link", "lp", "probability", "utility", "fitted",
-    "mean", "lp", "probs", "response", "response", "link", "unconditional",
-    "response", "response", "link", "response", "link", "response",
-    "link", "quantile", "response", "link", "probs", "response",
-    "expvalue", "linpred", "prob", "response", "prob", "count", "zero"
+    "prob", "class", "probs", "latent", "probs", "response", "mean",
+    "E", "Ep", "p", "response", "response", "link", "expected", "detection",
+    "latent_N", "invlink(link)", "response", "link", "lp", "probability",
+    "utility", "fitted", "mean", "lp", "probs", "response", "link",
+    "lp", "mean", "probs", "response", "link", "response", "response",
+    "link", "unconditional", "response", "response", "link", "response",
+    "link", "response", "link", "quantile", "response", "link", "probs",
+    "response", "expvalue", "linpred", "prob", "response", "prob",
+    "count", "zero"
   ),
   stringsAsFactors = FALSE
 )
