@@ -95,82 +95,87 @@
     return(mydf)
   }
 
-  # check if outcome is log-transformed, and if so,
-  # back-transform predicted values to response scale
+  # skip for multivariate response models
+  if (insight::is_multivariate(model)) {
+    # tell user
+    if (verbose) {
+      insight::format_alert("Back-transforming response variables is not carried out for multivariate-response models.")
+    }
+    return(mydf)
+  }
+
+  # we need the string of the response variable, to get information about transformation
   if (is.null(response.name)) {
     rv <- insight::find_terms(model)[["response"]]
   } else {
+    # for pool_predictions(), we have no model object, but the response-string
     rv <- response.name
   }
 
-  if (any(grepl("log\\((.*)\\)", rv))) {
-    if (back.transform) {
-      # do we have log-log models?
-      if (grepl("log\\(log\\((.*)\\)\\)", rv)) {
-        mydf$predicted <- exp(exp(mydf$predicted))
-        if (.obj_has_name(mydf, "conf.low") && .obj_has_name(mydf, "conf.high")) {
-          mydf$conf.low <- exp(exp(mydf$conf.low))
-          mydf$conf.high <- exp(exp(mydf$conf.high))
-        }
-      } else {
-        plus_minus <- eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\2", rv)))
-        if (is.null(plus_minus)) plus_minus <- 0
-        mydf$predicted <- exp(mydf$predicted) - plus_minus
-        if (.obj_has_name(mydf, "conf.low") && .obj_has_name(mydf, "conf.high")) {
-          mydf$conf.low <- exp(mydf$conf.low) - plus_minus
-          mydf$conf.high <- exp(mydf$conf.high) - plus_minus
-        }
-      }
-      if (verbose) {
-        insight::format_alert("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale.") # nolint
-      }
-    } else if (verbose) {
-      insight::format_alert("Model has log-transformed response. Predictions are on log-scale.")
+  # for pool_predictions(), we have no model object, but rather the response-string
+  if (is.null(model)) {
+    # find possible transformations from response-string
+    transformation <- insight::find_transformation(rv)
+  } else {
+    # find possible transformations from model
+    transformation <- insight::find_transformation(model)
+  }
+
+  # skip if no information available, or no transformation applies
+  if (is.null(transformation) || identical(transformation, "identity")) {
+    return(mydf)
+  }
+
+  # transformed response, but no back-transform requested?
+  # Tell user and return untransformed predictions
+  if (!back.transform) {
+    if (verbose) {
+      insight::format_alert(
+        paste0("Model has ", transformation, " transformed response. Predictions are on transformed scale.")
+      )
     }
+    return(mydf)
   }
 
-  trans_fun <- NULL
-  if (any(grepl("log1p\\((.*)\\)", rv))) {
-    trans_fun <- function(x) expm1(x)
+  # for pool_predictions(), we have no model object, but rather the response-string
+  if (is.null(model)) {
+    # get inverse transformation function response-string
+    trans_fun <- insight::get_transformation(rv, verbose = verbose)$inverse
+  } else {
+    # get inverse transformation function from model
+    trans_fun <- insight::get_transformation(model, verbose = verbose)$inverse
   }
 
-  if (any(grepl("log10\\((.*)\\)", rv))) {
-    trans_fun <- function(x) 10^x
+  # Tell user about transformation
+  if (verbose && !is.null(trans_fun)) {
+    insight::format_alert(
+      paste0("Model has ", transformation, "-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the transformed scale.") # nolint
+    )
   }
 
-  if (any(grepl("log2\\((.*)\\)", rv))) {
-    trans_fun <- function(x) 2^x
-  }
-
-  if (any(grepl("sqrt\\((.*)\\)", rv))) {
-    if (back.transform) {
-      plus_minus <- eval(parse(text = gsub("sqrt\\(([^,\\+)]*)(.*)\\)", "\\2", rv)))
-      if (is.null(plus_minus)) plus_minus <- 0
-      mydf$predicted <- mydf$predicted^2 - plus_minus
-      if (.obj_has_name(mydf, "conf.low") && .obj_has_name(mydf, "conf.high")) {
-        mydf$conf.low <- mydf$conf.low^2 - plus_minus
-        mydf$conf.high <- mydf$conf.high^2 - plus_minus
-      }
-      if (verbose) {
-        insight::format_alert("Model has sqrt-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the sqrt-scale.") # nolint
-      }
-    } else if (verbose) {
-      insight::format_alert("Model has sqrt-transformed response. Predictions are on sqrt-scale.")
+  if (startsWith(transformation, "sqrt")) {
+    # handle sqrt-transformed response separately - might be "sqrt(x + 1)"
+    plus_minus <- eval(parse(text = gsub("sqrt\\(([^,\\+)]*)(.*)\\)", "\\2", rv)))
+    if (is.null(plus_minus)) plus_minus <- 0
+    mydf$predicted <- mydf$predicted^2 - plus_minus
+    if (all(c("conf.low", "conf.high") %in% colnames(mydf))) {
+      mydf$conf.low <- mydf$conf.low^2 - plus_minus
+      mydf$conf.high <- mydf$conf.high^2 - plus_minus
     }
-  }
-
-  if (!is.null(trans_fun)) {
-    if (back.transform) {
-      mydf$predicted <- trans_fun(mydf$predicted)
-      if (.obj_has_name(mydf, "conf.low") && .obj_has_name(mydf, "conf.high")) {
-        mydf$conf.low <- trans_fun(mydf$conf.low)
-        mydf$conf.high <- trans_fun(mydf$conf.high)
-      }
-      if (verbose) {
-        insight::format_alert("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale.") # nolint
-      }
-    } else if (verbose) {
-      insight::format_alert("Model has log-transformed response. Predictions are on log-scale.")
+  } else if (startsWith(transformation, "log(") && transformation != "log-log") {
+    # handle log-transformed response separately - might be "log(x + 1)"
+    plus_minus <- eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\2", rv)))
+    if (is.null(plus_minus)) plus_minus <- 0
+    mydf$predicted <- exp(mydf$predicted) - plus_minus
+    if (all(c("conf.low", "conf.high") %in% colnames(mydf))) {
+      mydf$conf.low <- exp(mydf$conf.low) - plus_minus
+      mydf$conf.high <- exp(mydf$conf.high) - plus_minus
+    }
+  } else if (!is.null(trans_fun)) {
+    mydf$predicted <- trans_fun(mydf$predicted)
+    if (all(c("conf.low", "conf.high") %in% colnames(mydf))) {
+      mydf$conf.low <- trans_fun(mydf$conf.low)
+      mydf$conf.high <- trans_fun(mydf$conf.high)
     }
   }
 
@@ -200,39 +205,39 @@
     return(mydf)
   }
 
-  if (any(grepl("log\\((.*)\\)", rv))) {
-    # do we have log-log models?
-    if (grepl("log\\(log\\((.*)\\)\\)", rv)) {
-      mydf$response <- log(log(mydf$response))
-    } else {
+  # find transformation
+  if (is.null(model)) {
+    # find possible transformations from response-string
+    transformation <- insight::find_transformation(rv)
+  } else {
+    # find possible transformations from model
+    transformation <- insight::find_transformation(model)
+  }
+
+  # get transformation function
+  if (is.null(model)) {
+    # get inverse transformation function response-string
+    trans_fun <- insight::get_transformation(rv, verbose = FALSE)$transformation
+  } else {
+    # get inverse transformation function from model
+    trans_fun <- insight::get_transformation(model, verbose = FALSE)$transformation
+  }
+
+  if (!is.null(transformation) && !identical(transformation, "identity") && !is.null(trans_fun)) {
+    if (startsWith(transformation, "sqrt")) {
+      # handle sqrt-transformed response separately - might be "sqrt(x + 1)"
+      plus_minus <- eval(parse(text = gsub("sqrt\\(([^,\\+)]*)(.*)\\)", "\\2", rv)))
+      if (is.null(plus_minus)) plus_minus <- 0
+      mydf$response <- sqrt(mydf$response) + plus_minus
+    } else if (startsWith(transformation, "log(") && transformation != "log-log") {
+      # handle log-transformed response separately - might be "log(x + 1)"
       plus_minus <- eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\2", rv)))
       if (is.null(plus_minus)) plus_minus <- 0
       mydf$response <- log(mydf$response) + plus_minus
+    } else if (!is.null(trans_fun)) {
+      mydf$response <- trans_fun(mydf$response)
     }
   }
 
-  trans_fun <- NULL
-  if (any(grepl("log1p\\((.*)\\)", rv))) {
-    trans_fun <- function(x) log1p(x)
-  }
-
-  if (any(grepl("log10\\((.*)\\)", rv))) {
-    trans_fun <- function(x) log10(x)
-  }
-
-  if (any(grepl("log2\\((.*)\\)", rv))) {
-    trans_fun <- function(x) log2(x)
-  }
-
-  if (any(grepl("sqrt\\((.*)\\)", rv))) {
-    plus_minus <- eval(parse(text = gsub("sqrt\\(([^,\\+)]*)(.*)\\)", "\\2", rv)))
-    if (is.null(plus_minus)) plus_minus <- 0
-    mydf$response <- sqrt(mydf$response) + plus_minus
-  }
-
-  if (!is.null(trans_fun)) {
-    mydf$response <- trans_fun(mydf$response)
-  }
-
   mydf
 }
