@@ -11,27 +11,27 @@ m4 <- pscl::hurdle(count ~ mined | mined, dist = "poisson", zero.dist = "binomia
 m5 <- suppressWarnings(pscl::zeroinfl(count ~ mined | mined, dist = "negbin", link = "log", data = Salamanders))
 
 test_that("ggpredict, pscl", {
-  expect_s3_class(ggpredict(m1, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggpredict(m1, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggpredict(m2, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggpredict(m2, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggpredict(m3, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggpredict(m3, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggpredict(m4, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggpredict(m4, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggpredict(m5, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggpredict(m5, "mined", type = "fe.zi"), "data.frame")
+  expect_s3_class(ggpredict(m1, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggpredict(m1, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggpredict(m2, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggpredict(m2, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggpredict(m3, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggpredict(m3, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggpredict(m4, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggpredict(m4, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggpredict(m5, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggpredict(m5, "mined", type = "zero_inflated"), "data.frame")
 })
 
 test_that("ggpredict, pscl", {
   skip_on_cran()
   set.seed(123)
-  pr <- ggpredict(m1, "mined", type = "fe.zi")
+  pr <- ggpredict(m1, "mined", type = "zero_inflated")
   expect_equal(pr$conf.low, c(0.1731, 2.0172), tolerance = 1e-3)
 
   model <- pscl::zeroinfl(count ~ mined * spp | mined * spp, dist = "poisson", data = Salamanders)
   set.seed(123)
-  pr <- ggpredict(model, c("mined", "spp"), type = "fe.zi")
+  pr <- ggpredict(model, c("mined", "spp"), type = "zero_inflated")
   expect_equal(
     pr$conf.low,
     c(0, 0, 0.03704, 1e-05, 1e-05, 0.14815, 0.13418, 1.61886,
@@ -42,42 +42,42 @@ test_that("ggpredict, pscl", {
 
 test_that("ggemmeans, pscl", {
   skip_if_not_installed("emmeans")
-  expect_s3_class(ggemmeans(m1, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggemmeans(m1, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggemmeans(m2, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggemmeans(m2, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggemmeans(m3, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggemmeans(m3, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggemmeans(m4, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggemmeans(m4, "mined", type = "fe.zi"), "data.frame")
-  expect_s3_class(ggemmeans(m5, "mined", type = "fe"), "data.frame")
-  expect_s3_class(ggemmeans(m5, "mined", type = "fe.zi"), "data.frame")
+  expect_s3_class(ggemmeans(m1, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggemmeans(m1, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggemmeans(m2, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggemmeans(m2, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggemmeans(m3, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggemmeans(m3, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggemmeans(m4, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggemmeans(m4, "mined", type = "zero_inflated"), "data.frame")
+  expect_s3_class(ggemmeans(m5, "mined", type = "fixed"), "data.frame")
+  expect_s3_class(ggemmeans(m5, "mined", type = "zero_inflated"), "data.frame")
 })
 
 test_that("compare, pscl", {
   skip_if_not_installed("emmeans")
-  p1 <- ggemmeans(m1, "mined", type = "fe")
-  p2 <- ggpredict(m1, "mined", type = "fe")
+  p1 <- ggemmeans(m1, "mined", type = "fixed")
+  p2 <- ggpredict(m1, "mined", type = "fixed")
   expect_equal(p1$predicted[1], p2$predicted[1], tolerance = 1e-3)
 
-  p1 <- ggemmeans(m1, "mined", type = "fe.zi")
-  p2 <- ggpredict(m1, "mined", type = "fe.zi")
+  p1 <- ggemmeans(m1, "mined", type = "zero_inflated")
+  p2 <- ggpredict(m1, "mined", type = "zero_inflated")
   expect_equal(p1$predicted[1], p2$predicted[1], tolerance = 1e-3)
 
-  p1 <- ggemmeans(m2, "mined", type = "fe")
-  p2 <- ggpredict(m2, "mined", type = "fe")
+  p1 <- ggemmeans(m2, "mined", type = "fixed")
+  p2 <- ggpredict(m2, "mined", type = "fixed")
   expect_equal(p1$predicted[1], p2$predicted[1], tolerance = 1e-3)
 
-  p1 <- ggemmeans(m2, "mined", type = "fe.zi")
-  p2 <- ggpredict(m2, "mined", type = "fe.zi")
+  p1 <- ggemmeans(m2, "mined", type = "zero_inflated")
+  p2 <- ggpredict(m2, "mined", type = "zero_inflated")
   expect_equal(p1$predicted[1], p2$predicted[1], tolerance = 1e-3)
 
-  p1 <- ggemmeans(m5, "mined", type = "fe")
-  p2 <- ggpredict(m5, "mined", type = "fe")
+  p1 <- ggemmeans(m5, "mined", type = "fixed")
+  p2 <- ggpredict(m5, "mined", type = "fixed")
   expect_equal(p1$predicted[1], p2$predicted[1], tolerance = 1e-3)
 
-  p1 <- ggemmeans(m5, "mined", type = "fe.zi")
-  p2 <- ggpredict(m5, "mined", type = "fe.zi")
+  p1 <- ggemmeans(m5, "mined", type = "zero_inflated")
+  p2 <- ggpredict(m5, "mined", type = "zero_inflated")
   expect_equal(p1$predicted[1], p2$predicted[1], tolerance = 1e-3)
 })
 
@@ -128,7 +128,7 @@ test_that("pscl, validate all functions against predict", {
 
   out1 <- predict(m, newdata = nd, type = "response")
   out2 <- ggpredict(m, "spp", type = "zero_inflated")
-  out3 <- ggaverage(m, "spp")
+  out3 <- ggaverage(m, "spp", type = "zero_inflated")
   out4 <- marginaleffects::avg_predictions(m, variables = "spp")
 
   expect_equal(out1, out2$predicted, tolerance = 1e-3, ignore_attr = TRUE)
